@@ -1,13 +1,10 @@
-# flake8: noqa
-__version__ = "0.6.1"
+__version__ = "0.7.0"
 __author__ = "DESHIMA software team"
 
 
-# subpackages
-from . import core
-
-
 # submodules
+from . import array
+from . import cube
 from . import io
 from . import models
 from . import logging
@@ -16,7 +13,8 @@ from . import utils
 
 
 # aliases
-from .core import *
+from .array import *
+from .cube import *
 from .logging import *
 
 
